<?php
namespace Folha\Entities;

use HCM\Util\DateUtil;
use Importacao\Logic\Integracao\ProjetoImportacao;

class MigAltesalario extends Base\MigAltesalario
{

    const DEFAULT_NROCORRENCIA = '1';
    const DEFAULT_NRTIPOALTERA = '2';
    const DEFAULT_IDTPSALARAIO = 'MENSAL';
    const DEFAULT_NRTPMODALIDSAL = '1';

    /**
     * @param $nraltesalario
     * @return \Folha\Entities\MigAltesalario
     */
    public function setNraltesalario ($nraltesalario) {
        $nraltesalario = \Importacao\Logic\Validacoes::verificaChaveDuplicada('GPE_ALTESALARIO', 'NRALTESALARIO', ProjetoImportacao::getNrorg(), $nraltesalario);
        $this->nraltesalario = $nraltesalario;
    }

    /**
     * @param $nrvinculom
     * @return \Folha\Entities\MigAltesalario
     */
    public function setNrvinculom ($nrvinculom) {
        $nrvinculom = \Importacao\Logic\Validacoes::verificaChaveMae('GPE_VINCULOM', 'NRVINCULOM', ProjetoImportacao::getNrorg(), $nrvinculom);
        $this->nrvinculom = $nrvinculom;
    }

    /**
     * @param $nrocorrencia
     * @return \Folha\Entities\MigAltesalario
     */
    public function setNrocorrencia ($nrocorrencia) {
        if (empty($nrocorrencia)) {
            $nrocorrencia = self::DEFAULT_NROCORRENCIA;
        }

        $this->nrocorrencia = $nrocorrencia;
    }

    /**
     * @param $nrtipoaltera
     * @return \Folha\Entities\MigAltesalario
     */
    public function setNrtipoaltera ($nrtipoaltera) {
        if (empty($nrtipoaltera)) {
            $nrtipoaltera = self::DEFAULT_NRTIPOALTERA;
        }

        $this->nrtipoaltera = $nrtipoaltera;
    }

    /**
     * @param $vrsalario
     * @throws \Exception
     * @return \Folha\Entities\MigAltesalario
     */
    public function setVrsalario ($vrsalario) {
        if ($vrsalario == '' || empty($vrsalario)) {
            $this->vrsalario = 0;
        }

        $vrsalario = str_replace(',', '.', $vrsalario);

        $this->vrsalario = $vrsalario;
    }

    /**
     * @param $idtpsalario
     * @return \Folha\Entities\MigAltesalario
     */
    public function setIdtpsalario ($idtpsalario) {
        if (empty($idtpsalario)) {
            $idtpsalario = self::DEFAULT_IDTPSALARAIO;
        }
        $this->idtpsalario = $idtpsalario;
    }

    /**
     * @param $nrtpmodalidsal
     * @return \Folha\Entities\MigAltesalario
     */
    public function setNrtpmodalidsal ($nrtpmodalidsal) {
        if (empty($nrtpmodalidsal)) {
            $nrtpmodalidsal = self::DEFAULT_NRTPMODALIDSAL;
        }

        $this->nrtpmodalidsal = $nrtpmodalidsal;
    }

    /**
     * @param $dtaltesalario
     * @throws \Exception
     * @return \Folha\Entities\MigAltesalario
     */
    public function setDtaltesalario ($dtaltesalario) {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtaltesalario)) {
            throw new \Exception("Campo Obrigatório - Data da Alteração: Data '$dtaltesalario' com formato inválido ou em branco.");
        }

        if (!($dtaltesalario instanceof \DateTime)) {
            $dtaltesalario = DateUtil::getDataDeString($dtaltesalario);
        }

        $this->dtaltesalario = $dtaltesalario;
    }

    /**
     * @param $dtultatu
     * @throws \Exception
     * @return \Folha\Entities\MigAltesalario
     */
    public function setDtultatu ($dtultatu) {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtultatu)) {
            throw new \Exception("Data '$dtultatu' com formato inválido ou em branco.");
        }

        if (!($dtultatu instanceof \DateTime)) {
            $dtultatu = DateUtil::getDataDeString($dtultatu);
        }

        $this->dtultatu = $dtultatu;
    }

    /**
     * @param $dtinclusao
     * @throws \Exception
     * @return \Folha\Entities\MigAltesalario
     */
    public function setDtinclusao ($dtinclusao) {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtinclusao)) {
            throw new \Exception("Data '$dtinclusao' com formato inválido ou em branco.");
        }

        if (!($dtinclusao instanceof \DateTime)) {
            $dtinclusao = DateUtil::getDataDeString($dtinclusao);
        }

        $this->dtinclusao = $dtinclusao;
    }

}